




# StartApp 

simple boilerplate ready for development 

## notes
- Currently supported for  frameworks:  FastAPi, Flask, Django


### Installation ###

```sh
 $ pip install startapp
```





# Contributing
Fell free to open issue and send pull request.

